@@ -1,4 +1,5 @@
 """ Tests for exmod subcommand """
+
 from ast import ClassDef
 from functools import partial
 from io import StringIO
@@ -44,7 +45,9 @@ class TestExMod(TestCase):
                     emit_name="class",
                     blacklist=tuple(),
                     whitelist=tuple(),
+                    mock_imports=True,
                     output_directory=new_module_dir,
+                    no_word_wrap=None,
                     dry_run=False,
                 )
                 self._check_emission(new_module_dir)
@@ -68,7 +71,9 @@ class TestExMod(TestCase):
                     emit_name="class",
                     blacklist=(".".join((self.module_name,) * 2),),
                     whitelist=tuple(),
+                    mock_imports=True,
                     output_directory=new_module_dir,
+                    no_word_wrap=None,
                     dry_run=False,
                 )
                 self.assertListEqual(listdir(new_module_dir), [])
@@ -92,7 +97,9 @@ class TestExMod(TestCase):
                     emit_name="class",
                     blacklist=tuple(),
                     whitelist=(".".join((existent_module_name,) * 2),),
+                    mock_imports=True,
                     output_directory=new_module_dir,
+                    no_word_wrap=None,
                     dry_run=False,
                 )
 
@@ -155,18 +162,22 @@ class TestExMod(TestCase):
                                                     partial(path.join, "child_dir"),
                                                     (
                                                         INIT_FILENAME,
-                                                        "child.py",
+                                                        "child{sep}py".format(
+                                                            sep=extsep
+                                                        ),
                                                         path.join(
                                                             "grandchild_dir",
                                                             INIT_FILENAME,
                                                         ),
                                                         path.join(
                                                             "grandchild_dir",
-                                                            "grandchild.py",
+                                                            "grandchild{sep}py".format(
+                                                                sep=extsep
+                                                            ),
                                                         ),
                                                     ),
                                                 ),
-                                                "parent.py",
+                                                "parent{sep}py".format(sep=extsep),
                                             ),
                                         ),
                                     )
@@ -186,10 +197,26 @@ class TestExMod(TestCase):
         with TemporaryDirectory() as tempdir, self.assertRaises(ModuleNotFoundError):
             exmod(
                 module=tempdir,
-                emit_name="cjvxclkvjclxkjvlcx",
+                emit_name="cool_name",
                 blacklist=tuple(),
                 whitelist=tuple(),
+                mock_imports=True,
                 output_directory=path.join(tempdir, "nonexistent"),
+                no_word_wrap=None,
+                dry_run=False,
+            )
+
+    def test_exmod_no_module(self) -> None:
+        """Tests that ModuleNotFound error is raised when module is not installed"""
+        with TemporaryDirectory() as tempdir, self.assertRaises(ModuleNotFoundError):
+            exmod(
+                module="fubar",
+                emit_name="uncool_name",
+                blacklist=tuple(),
+                whitelist=tuple(),
+                mock_imports=True,
+                output_directory=path.join(tempdir, "nonexistent"),
+                no_word_wrap=None,
                 dry_run=False,
             )
 
@@ -204,7 +231,9 @@ class TestExMod(TestCase):
                 emit_name=None,
                 blacklist=tuple(),
                 whitelist=tuple(),
+                mock_imports=True,
                 output_directory=output_directory,
+                no_word_wrap=None,
                 dry_run=False,
             )
 
@@ -226,7 +255,9 @@ class TestExMod(TestCase):
                         emit_name="class",
                         blacklist=tuple(),
                         whitelist=tuple(),
+                        mock_imports=True,
                         output_directory=new_module_dir,
+                        no_word_wrap=None,
                         dry_run=True,
                     )
                     r = f.getvalue()
@@ -384,7 +415,7 @@ class TestExMod(TestCase):
         :param tempdir: Temporary directory
         :type tempdir: ```str```
 
-        :returns: tempdir
+        :return: tempdir
         :rtype: ```str```
         """
         self.module_name, self.gold_dir = path.basename(tempdir), tempdir
@@ -511,7 +542,7 @@ class TestExMod(TestCase):
                 :param _folder: Folder to join on
                 :type _folder: ```str``
 
-                :returns: Open IO
+                :return: Open IO
                 :rtype: ```open```
                 """
                 return open(
@@ -531,15 +562,19 @@ class TestExMod(TestCase):
 
                 with _open(gen_folder) as gen, _open(gold_folder) as gold:
                     gen_ir, gold_ir = map(
-                        lambda node: parse.class_(
-                            next(
-                                filter(
-                                    rpartial(isinstance, ClassDef),
-                                    ast_parse(node.read()).body,
+                        lambda ir: ir["_internal"].__delitem__("original_doc_str")
+                        or ir,
+                        map(
+                            lambda node: parse.class_(
+                                next(
+                                    filter(
+                                        rpartial(isinstance, ClassDef),
+                                        ast_parse(node.read()).body,
+                                    )
                                 )
-                            )
+                            ),
+                            (gen, gold),
                         ),
-                        (gen, gold),
                     )
                     self.assertDictEqual(gold_ir, gen_ir)
 
@@ -565,7 +600,5 @@ class TestExMod(TestCase):
             "EXIT_SUCCESS not reached",
         )
 
-    maxDiff = None
-
 
 unittest_main()
